import {Dialog, Toast} from 'vant'
import store from '~/store'
import rehabilitationApi from '~/api/rehabilitation'
import followupApi from '~/api/followup'
import imServe from '~/api/api-im'
import moment from 'moment' 
import cryptoUtils from "~/utils/cryptoUtils"
import imgPathUtils from '~/utils/imgPathUtils'
/* 类型：week（按周），month（按月）；
	num: 一次几周，一次几个月
	day指定时间：1~7（按周） 或 1~12（按月）
*/
function getStartDate(type, day) {
	if(type === "week") {
		// 当前周
		var curDay = moment().isoWeekday();
		if(curDay >= day) {
			return moment().isoWeekday(day+7);
		} else {
			return moment().isoWeekday(day);
		}
	} else if(type === "month"){
		// 当前年份
		var curYear = moment().year();
		// 当前月份
		var curMonth = moment().month() + 1;
		// 当前日期
		var curDate = moment().date();
		if(curDate >= day) {
			return moment({year: curYear, month: curMonth, date : day}); // 注：month是从0开始算，范围：0~11
		} else {
			return moment({year: curYear, month: curMonth - 1, date : day});
		}
	}
}

/* 按周获取日期（最近3个月内）
	num: 一次几周
	day指定时间：1~7
*/
function getFreDateArrByWeek(num, day) {
	// 开始时间
	var startDate = getStartDate("week",day);
	// 3个月后的截止时间
	var maxDate = startDate.clone().month(startDate.month() + 3);
	// 符合条件的3个月内的日期数组
	var result = [];
	var buff = startDate.clone();
	while(buff.isSameOrBefore(maxDate)) {
		result.push(buff.clone());
		buff.isoWeekday(buff.isoWeekday()+7*num);
	}
	
	return result;
}

/* 按周获取日期（最近12个月内）
	num: 一次几个月
	day指定时间：1~28
*/
function getFreDateArrByMonth(num, day) {
	// 开始时间
	var startDate = getStartDate("month",day);
	// 12个月后的截止时间
	var maxDate = startDate.clone().month(startDate.month() + 12);
	// 符合条件的12个月内的日期数组
	var result = [];
	var buff = startDate.clone();
	while(buff.isSameOrBefore(maxDate)) {
		result.push(buff.clone());
		buff.month(buff.month()+num);
	}
	
	return result;
}

/* fre频率：weekN（N周/次），monthN（N月/次）；
	day指定时间：1~7（按周） 或 1~12（按月）
*/
function getFreDateArr(fre, day) {
	var reg = /^(week|month)(\d+)$/,
		types = reg.exec(fre),
		type = types[1],
		num = +types[2];
		
	if(type === "week") {
		return getFreDateArrByWeek(num, day);
	} else if(type === "month" && day <= 28) {
		return getFreDateArrByMonth(num, day);
	}
	
	throw new Error("参数有误！")
}

function getDynamicStatusInfo(status){
	var name = "",
		color = "";
	switch(status){
		case "未结束":
			name = "未结束";
			color = "c-ff9526";
			break;
		case 1:
			name = "已完成";
			color = "c-999";
			break;
		case "已结束":
			name = "已结束";
			color = "c-17b3ec";
			break;
		case "未回复":
			name = "未回复";
			color = "c-ff5e6c";
			break;
		default:
			name = status;
			color = "c-999";
			break;
	}
	return {name: name, color: color};
}

function getWeekName(day){
	switch(day){
		case 0: 
			return "星期天";
		case 1:
			return "星期一";
		case 2:
			return "星期二";
		case 3:
			return "星期三";
		case 4:
			return "星期四";
		case 5:
			return "星期五";
		case 6:
			return "星期六";
	}
}

function getStatusInfo(status){
	//status = （0未完成，1已完成，2已预约）
	var name = "",
		color = "";
	switch(status){
		case 0:
			name = "未完成";
			color = "c-ff5e6c";
			break;
		case 1:
			name = "已完成";
			color = "c-999";
			break;
		case 2:
			name = "已预约";
			color = "c-17b3ec";
			break;
	}
	return {name: name, color: color};
}

function getMsgContent(msg){
	var content = "";
	switch(msg.contentType){
		case 0:
		case 1:
		case 6:
		case 8:
			content = msg.content;
			break;
		case 2:
		case 9:
			content = "【图片】";
			break;
		case 3:
			content = "【语音】";
			break;
		case 4:
			content = "【文章】";
			break;
		case 12:
			content = "【视频】";
			break;
		case 18:
			content = "【居民名片】";
			break;
		case 19:
			content = "【聊天记录】";
			break;
	}
	if(!content){
		content="暂无消息";
	}
	return content;
}

function getContent(value, type) {
	var res = value, isImg = false
	if(type==2 || type==9){
		res = imgPathUtils.setImgUlr(res);
		isImg = true
	}else if(type==3){
		res = '【语音】';
	}else if(type==19){
		res = '【聊天记录】';
	}else if(type==12){
		res = '【视频】';
	}
	return {isImg: isImg, content: res};
}

function showLoading(text){
	vant.Toast.loading({
		duration: 0,
		message: text || '提交中...',
		// forbidClick: true,
		// loadingType: 'spinner',
	});
}
//打电话
function huanzhePhone({patientInfo, detailId}) {
	return new Promise((resolve, reject)=>{
		if(patientInfo.mobile){
			var user = store.getters.user
			Dialog.confirm({
				title: '呼叫患者',
				message: "请问您是否确认呼叫" + patientInfo.name + ":" + patientInfo.mobile + "？",
				confirmButtonText: '呼叫'
			})
			.then(() => {
				window.location.href = 'tel:' + patientInfo.mobile
				rehabilitationApi
					.planDetailAfterCall({
						planDetailId: detailId,
						doctorCode: user.id,
					})
					.then(res=>{
						resolve()
					})
			}).catch(()=>{
				reject('取消')
			})
		}
		else {
			reject()
		}
	})
}

//提醒患者
function tixingHuanzhe({patientName, patiCode, planId, detailId, taskCode, reservationType}){
	return new Promise((resolve, reject)=>{
		// 1康复指导2康复下转3复诊提醒4上门服务提醒5家签提醒
		var msg, num
		if(taskCode=='7'){
			num='3'
			msg = "请问您是否确认提醒"+patientName+"居民进行复诊？"
		}else if(taskCode=='4'){
			num='4'
			msg = "请问您是否确认提醒"+patientName+"居民预约上门护理服务？"
		}

		Dialog.confirm({
				title: '提示',
				message: msg,
				confirmButtonText: '确定'
			})
			.then(() => {
				showLoading('提交中..')
				var user = store.getters.user
				rehabilitationApi
					.sendSpecialistWeixinMessage({
						patient: patiCode,
						doctor: user.id,
						type: num,
						relationCode: detailId,
						planId: planId,
						reservationType: reservationType || ''  //复诊类型:1线上，2线下，3远程   目前只有线下
					})
					.then(res=>{
						return resolve()
						// if(needSave){
						// 	saveRehabilitationOperateRecord({
						// 		patientName, 
						// 		patiCode, 
						// 		planId, 
						// 		detailId, 
						// 		taskCode, 
						// 		followId, 
						// 		followFlag, 
						// 		relationCode, 
						// 		needUpdate
						// 	})
						// } else {
						// 	resolve()
						// }
					})
					.catch(err=>{
						reject(err)
					})
			})
	})
}

//完成服务记录
function saveRehabilitationOperateRecord({
		patientName, patiCode, detailId, taskCode, //必填
		followId, followFlag, relationCode, frequencyCode, 
		status, node, relationRecordImg
	}){
	
	return new Promise((resolve, reject)=>{
		var user = store.getters.user
		var params = {
			rehabilitationDetailId: detailId,
			patientCode: patiCode,
			patientName: patientName,
			doctorCode: user.id,
			doctorName: user.name,
			relationRecordType: taskCode,
			relationRecordCode: "",
			status: status || 0,
			node: node || "",
			relationRecordImg: relationRecordImg || ""
		}
		
		// if(vm.detailInfo.type == '6'){
		if(taskCode == 6 && !frequencyCode){
			//不限频次
			params.relationCode = followId || ""
			params.flag = followFlag||""
			if(params.flag == 2){
				//临时随访
				params.status = 1
			}
		}
		if(relationCode){
			params.relationCode = relationCode
		}
		console.log('saveRehabilitationOperateRecord params', params)
		showLoading('提交中..')
		rehabilitationApi
			.saveRehabilitationOperateRecord({
				dataJson: JSON.stringify(params)
			})
			.then(res=>{
				resolve(res)

				// if(needUpdate){
				// 	updateNoteAndImageRehabilitationOperate()
				// }else{
				// 	resolve()
				// }
			})
			.catch(err=>{
				console.log(err)
				// console.error('saveRehabilitationOperateRecord', err)
				reject('saveRehabilitationOperateRecord'+ err)
			})
	})
}

//完成服务记录(已完成)
function updateNoteAndImageRehabilitationOperate({recordId, detailId, taskCode, followId, followFlag, text, status, imageList}){
	return new Promise((resolve, reject)=>{
		var params = {
			recordId,
			planDetailId: detailId,
			node: text || '',
			image: (imageList&&[imageList.join(',')]) || '',
		}
	
		if(status!==undefined){
			params.status = status
		}
		if(taskCode == '6'){
			params.relationCode = followId||""
			params.flag = followFlag||""
		}
		console.log('updateNoteAndImageRehabilitationOperate params', params)
		showLoading('提交中..')
		rehabilitationApi
			.updateNoteAndImageRehabilitationOperate(params)
			.then(res=>{
				resolve(res)
			})
			.catch(err=>{
				// console.error('updateNoteAndImageRehabilitationOperate', err)
				reject('updateNoteAndImageRehabilitationOperate'+ err)
			})
	})
}

function openChatroom(peerId, peerName, vm, planParams){
	console.log({
        session_type: "2",
        userId: store.getters.user.id,
        peerId: peerId,
        session_name: peerName
	})
	imServe.createP2pSession({
        session_type: "2",
        userId: store.getters.user.id,
        peerId: peerId,
        session_name: peerName
	}).then(res=>{
		if(res.status==200){
			vm.$router.push({
				path: "/onlineChat/chatroom",
				query: {
					_rs_title: peerName,
					type: 20,
					sessionId: res.data.id,
					planParams: cryptoUtils.Encrypt(JSON.stringify(planParams))
				}
			})
		} else {
			Toast("创建会话失败")
		}
	})
}

function getFollowupDetailUrl({planItem, vm}){
	return new Promise((resolve, reject)=>{
		showLoading('请求中..')
		var followupInfo
		followupApi
			.getFollowup({
				id: Number(planItem.relationCode || planItem.recordRelationCode)
			})
			.then(res=>{
				followupInfo = res.obj
				var dictMap = {
					11: "m-guanxinbing",//冠心病
					12: "m-fukeyanzheng",//慢性妇科炎症
					13: "m-qianliexian",//慢性前列腺
					14: "m-ruxian",//慢性乳腺
					15: "m-shenbing",//慢性肾病
					16: "m-feibing",//慢性阻塞性肺病
					17: "m-naocuizhong",//脑卒中
					18: "m-zhifanggan",//脂肪肝
					19: "m-feiai", // 肺癌
					20: "m-changweibing" // 慢性胃肠病
				}
				// 十大病种
				if(followupInfo.followupClass>=11 && followupInfo.followupClass<=20) {
					// 妇科炎症、慢阻肺 需要判断是否是第一次随访
					if(followupInfo.followupClass==12 || followupInfo.followupClass==16) {
						return followupApi
							.isFirstTimeFollowup({ 
								patient: planItem.patient, 
								followupClass: followupInfo.followupClass, 
								followupId: planItem.frequencyCode? planItem.relationCode : planItem.recordRelationCode 
							})
							.then(res=>{
								debugger
								if(res.obj) {
									return "../../../html/suifang/html/v1/html/"+dictMap[followupInfo.followupClass]+'.html'
								} else {
									return "../../../html/suifang/html/v1/html/"+dictMap[followupInfo.followupClass]+'2.html'
								}
							})
							.catch((err) =>{
								console.error(err)
							})
					} else {
						return Promise.resolve("../../../html/suifang/html/v1/html/"+dictMap[followupInfo.followupClass]+'.html')
					}
				} else {
					return Promise.resolve("")
				}
			})
			.then(url=>{
				debugger
				if(url) {
					openWebview(url, {
						followup_id: vm.info.relationCode || vm.info.recordRelationCode,
						status: followupInfo.status,              
					});
				} else {
					vm.gotoUrl('/followup/startPlan', {
						followupId: followupInfo.id,
						start_plan: true,
					})
				}
				resolve()

				// if(res.status == 200) {
				// 	if(res.data) {
				// 		return "../../../html/suifang/html/v1/html/"+dictMap[followupInfo.followupClass]+'.html'
				// 	} else {
				// 		return "../../../html/suifang/html/v1/html/"+dictMap[followupInfo.followupClass]+'2.html'
				// 	}
		        // } else {
		        // 	mui.toast(res.msg);
		        // }
			})
	})
}


export {
	getFreDateArr,
	getDynamicStatusInfo,
	getWeekName,
	getStatusInfo,
	huanzhePhone,
	tixingHuanzhe,
	saveRehabilitationOperateRecord,
	updateNoteAndImageRehabilitationOperate,
	openChatroom,
	getMsgContent,
	getFollowupDetailUrl,
	getContent
}